<?php

// Set options array
$vx_theme_options = array(
	'accordian' => array(
		'type' => 'radio',
		'default' => 'yes',
		'options' => array(
			'1' => array(
				'value' => 'yes',
				'label' => __( 'Enabled', 'victorianxmas' )
			),
			'2' => array(
				'value' => 'no',
				'label' => __( 'Disabled', 'victorianxmas' )
			)
		)
	),
	'pt_width' => array(
		'type' => 'text',
		'default' => '150',
		'size' => 3,
		'maxlength' => 3,
		'numeric' => 1,
		'label' => __( 'Width:', 'victorianxmas' )
	),
	'pt_height' => array(
		'type' => 'text',
		'default' => '150',
		'size' => 3,
		'maxlength' => 3,
		'numeric' => 1,
		'label' => __( 'Height:', 'victorianxmas' )
	),
	'pt_crop' => array(
		'type' => 'radio',
		'default' => 'soft',
		'options' => array(
			'1' => array(
				'value' => 'soft',
				'label' => __( 'Soft (proportional)', 'victorianxmas' )
			),
			'2' => array(
				'value' => 'hard',
				'label' => __( 'Hard (fixed)', 'victorianxmas' )
			)
		)
	),
	'home_tag_cloud' => array(
		'type' => 'radio',
		'default' => 'yes',
		'options' => array(
			'1' => array(
				'value' => 'yes',
				'label' => __( 'Yes', 'victorianxmas' )
			),
			'2' => array(
				'value' => 'no',
				'label' => __( 'No', 'victorianxmas' )
			)
		)
	),
	'image_thickbox' => array(
		'type' => 'radio',
		'default' => 'yes',
		'options' => array(
			'1' => array(
				'value' => 'yes',
				'label' => __( 'Yes', 'victorianxmas' )
			),
			'2' => array(
				'value' => 'no',
				'label' => __( 'No', 'victorianxmas' )
			)
		)
	),
	'custom_excerpt' => array(
		'type' => 'text',
		'default' => '100',
		'size' => 3,
		'maxlength' => 3,
		'numeric' => 1,
		'label' => __( 'Number of words:', 'victorianxmas' )
	),
	'display_kses' => array(
		'type' => 'radio',
		'default' => 'yes',
		'options' => array(
			'1' => array(
				'value' => 'yes',
				'label' => __( 'Display', 'victorianxmas' )
			),
			'2' => array(
				'value' => 'no',
				'label' => __( 'Hide', 'victorianxmas' )
			)
		)
	)
);

// White list theme options
function victorianxmas_options_init() {
	register_setting( 'victorianxmas', 'victorianxmas_theme_options', 'victorianxmas_options_validate' );
}
add_action( 'admin_init', 'victorianxmas_options_init' );

// Add theme options page
function victorianxmas_options_add_page() {
	add_theme_page( __( 'Theme Options', 'victorianxmas' ), __( 'Theme Options', 'victorianxmas' ), 'edit_theme_options', 'victorianxmas', 'victorianxmas_options_do_page' );
}
add_action('admin_menu', 'victorianxmas_options_add_page');

// Load theme options stylesheet
function victorianxmas_options_add_style() {
	$css_file = get_template_directory() . '/library/vx-theme-options.css';
	$css_url = get_template_directory_uri() . '/library/vx-theme-options.css';
	if ( file_exists($css_file) ) {
		wp_register_style('victorianxmas_options_style', $css_url, '', '', 'screen');
	}
}
function victorianxmas_options_enqueue_style() {
	wp_enqueue_style('victorianxmas_options_style');
}
add_action('admin_init', 'victorianxmas_options_add_style');
add_action('admin_print_styles', 'victorianxmas_options_enqueue_style');

// Theme options form
function victorianxmas_options_do_page() {
	global  $vx_theme_options, $pagenow;
	$updated = false;
	if ( isset( $_REQUEST['updated'] ) || isset( $_REQUEST['settings-updated'] ) ) $updated = true;?>

	<div class="wrap">
	<?php screen_icon(); echo "<h2>" .  get_current_theme() . "</h2>";
	include 'vx-donate.php';?>

	<?php if ( $updated == true ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Your theme options have been saved', 'victorianxmas'); ?></strong></p></div>
	<?php endif; ?>

	<form method="post" action="options.php" id="victorianxmas_options"><div>
	<?php settings_fields( 'victorianxmas' ); ?>
	<?php $stored_options = get_option('victorianxmas_theme_options');
	?>

	<fieldset>
	<legend><?php _e('Collapsing sub-menus (vertical sidebar)', 'victorianxmas'); ?></legend>
	<?php $option_name = 'accordian';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset class="pt-size">
	<legend><?php _e('Featured Post Image Size', 'victorianxmas'); ?></legend>
	<?php $option_name = 'pt_width';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?><br />
	<?php $option_name = 'pt_height';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Featured Post Image Cropping', 'victorianxmas'); ?></legend>
	<?php $option_name = 'pt_crop';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Display tag cloud on main posts page', 'victorianxmas'); ?></legend>
	<?php $option_name = 'home_tag_cloud';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Use thickbox for attachment images', 'victorianxmas'); ?></legend>
	<?php $option_name = 'image_thickbox';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Post Excerpt Length', 'victorianxmas'); ?></legend>
	<?php $option_name = 'custom_excerpt';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<fieldset>
	<legend><?php _e('Allowed Tags (comment form)', 'victorianxmas'); ?></legend>
	<?php $option_name = 'display_kses';
	victorianxmas_options_sort( $vx_theme_options[$option_name], $stored_options, $option_name);?>
	</fieldset>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Update Theme', 'victorianxmas') ?>" /></p>

	</div></form>
</div>
	<?php
}

// sort inputs for display
function victorianxmas_options_sort($option_input, $stored_options, $name) {
	switch ($option_input['type']) {
		case 'radio':
		victorianxmas_options_do_radio($option_input['options'], $stored_options, $name, $option_input['default']);
		break;

		case 'text':
		victorianxmas_options_do_text($option_input, $stored_options, $name);
		break;

		default:
		break;
	}
}

// Radio button display
function victorianxmas_options_do_radio($radio_options, $stored_options, $name, $default) {
	if ( ! isset( $checked ) ) $checked = '';
	foreach ( $radio_options as $option ) {
		if ( isset( $stored_options[$name] ) ) {
			if( $stored_options[$name] == $option['value'] ) $checked = 'checked="checked"';
			else $checked = '';
		}
		else{
			if ( $option['value']  ==  $default ) $checked = 'checked="checked"';
			else $checked = '';
		}?>
		<label class="description" for="<?php echo $name;?>_<?php esc_attr_e( $option['value'] ); ?>"><input type="radio" id="<?php echo $name;?>_<?php esc_attr_e( $option['value'] ); ?>" name="victorianxmas_theme_options[<?php echo $name;?>]" value="<?php esc_attr_e( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label>
		<?php
	}
}

// Text input display
function victorianxmas_options_do_text($setting, $stored_options, $name) {
	if( isset( $stored_options[$name] ) ) {
		if( $setting['numeric'] == 1 ) {
			if( ctype_digit( $stored_options[$name] ) ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
		else {
			if( $stored_options[$name] != '' ) $current_value = $stored_options[$name];
			else $current_value = $setting['default'];
		}
	}
	else $current_value = $setting['default'];
	?>
	<label class="description text" for="<?php echo $name;?>"><?php echo $setting['label'];?></label> <input type="text" id="<?php echo $name;?>" name="victorianxmas_theme_options[<?php echo $name;?>]" size="<?php echo $setting['size'];?>" maxlength="<?php echo $setting['maxlength'];?>" value="<?php echo $current_value;?>" />
	<?php
}

// Sanitize and validate inputs
function victorianxmas_options_validate( $input ) {
	$new_input = array();
	global $vx_theme_options;
	$theme_option_names = array_keys($vx_theme_options);

	foreach($theme_option_names as $theme_option_name) {
		$option_type = $theme_option_name['type'];
		switch ($option_type) {
			case 'checkbox':
			$new_input[$theme_option_name] = ( $input[$theme_option_name] == 1 ? 1 : 0 );
			break;

			case 'text':
			$new_input[$theme_option_name] = wp_filter_nohtml_kses( $input[$theme_option_name] );
			break;

			case 'textarea':
			$new_input[$theme_option_name] = wp_filter_post_kses( $input[$theme_option_name] );
			break;

			default:
			$new_input[$theme_option_name] = $input[$theme_option_name];
		}
		if( !isset( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $theme_option_name['default'];
	}
	return $new_input;
}
